# Table of Contents

- [configuring-scim-in-okta](<./configuring-scim-in-okta.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Configuring SCIM in Okta](<./Configuring-SCIM-in-Okta.md>)
  - [Prerequisites](<./Configuring-SCIM-in-Okta/Prerequisites.md>)
  - [Configuring User Provisioning](<./Configuring-SCIM-in-Okta/Configuring-User-Provisioning.md>)
